pub struct Psram { /* private fields */ }
Enables externally-connected Pseudo-static RAM.
Initializes PSRAM.
Returns the address and size of the available in external memory.
TypeId
self
Returns the argument unchanged.
Calls U::from(self).
U::from(self)
That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.
[From]<T> for U
Self